==> paraview-3.8.1.tbz: lib/paraview-3.8/vtkPVServerCommonKit.cmake <==
# Directory containing class headers.
SET(VTK_PVSERVERCOMMON_HEADER_DIR "${VTK_INSTALL_PREFIX}/include/paraview-3.8")

# Classes in vtkPVServerCommon.
SET(VTK_PVSERVERCOMMON_CLASSES
  "vtkCacheSizeKeeper"
  "vtkCellIntegrator"
  "vtkClientConnection"
  "vtkConnectionIterator"
  "vtkMPISelfConnection"
  "vtkMultiProcessControllerHelper"
  "vtkPriorityHelper"
  "vtkProcessModuleConnection"
  "vtkProcessModuleConnectionManager"
  "vtkProcessModule"
  "vtkProcessModuleGUIHelper"
  "vtkPVAlgorithmPortsInformation"
  "vtkPVArrayInformation"
  "vtkPVCacheSizeInformation"
  "vtkPVClassNameInformation"
  "vtkPVClientServerIdCollectionInformation"
  "vtkPVCompositeDataInformation"
  "vtkPVCompositeDataInformationIterator"
  "vtkPVDataInformation"
  "vtkPVDataSetAttributesInformation"
  "vtkPVDataSizeInformation"
  "vtkPVDisplayInformation"
  "vtkPVEnvironmentInformation"
  "vtkPVEnvironmentInformationHelper"
  "vtkPVFileInformation"
  "vtkPVFileInformationHelper"
  "vtkPVGenericAttributeInformation"
  "vtkPVInformation"
  "vtkPVOpenGLExtensionsInformation"
  "vtkPVPlugin"
  "vtkPVPluginInformation"
  "vtkPVPluginLoader"
  "vtkPVProgressHandler"
  "vtkPVPythonModule"
  "vtkPVSelectionInformation"
  "vtkPVServerInformation"
  "vtkPVServerOptions"
  "vtkPVSILInformation"
  "vtkPVTemporalDataInformation"
  "vtkPVTestUtilities"
  "vtkPVTimerInformation"
  "vtkRemoteConnection"
  "vtkSelectionConverter"
  "vtkSelectionSerializer"
  "vtkSelfConnection"
  "vtkServerConnection"
  "vtkStringList"
  "vtkSynchronousMPISelfConnection"
  "vtkUndoElement"
  "vtkUndoSet"
  "vtkUndoStack"
  "vtkPVServerManagerPluginInterface"
  "vtkPVPythonPluginInterface"
  "vtkMPIMToNSocketConnection"
  "vtkMPIMToNSocketConnectionPortInformation"
  "vtkPVServerSocket"
  "vtkCommandOptions"
  "vtkCommandOptionsXMLParser"
  "vtkPVOptions"
  "vtkPVOptionsXMLParser"
  "vtkPVXMLParser"
  "vtkPVXMLElement")

# Abstract classes in vtkPVServerCommon.
SET(VTK_PVSERVERCOMMON_CLASSES_ABSTRACT
  "vtkCellIntegrator"
  "vtkProcessModuleConnection"
  "vtkProcessModuleGUIHelper"
  "vtkPVInformation"
  "vtkPVPlugin"
  "vtkRemoteConnection"
  "vtkUndoElement"
  "vtkPVServerManagerPluginInterface"
  "vtkPVPythonPluginInterface")

# Wrap-exclude classes in vtkPVServerCommon.
SET(VTK_PVSERVERCOMMON_CLASSES_WRAP_EXCLUDE
  "vtkConnectionIterator"
  "vtkPVPlugin"
  "vtkPVServerOptions"
  "vtkPVTestUtilities"
  "vtkPVServerManagerPluginInterface"
  "vtkPVPythonPluginInterface"
  "vtkPVServerSocket"
  "vtkCommandOptionsXMLParser"
  "vtkPVOptionsXMLParser")

# Set convenient variables to test each class.
FOREACH(class ${VTK_PVSERVERCOMMON_CLASSES})
  SET(VTK_CLASS_EXISTS_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_PVSERVERCOMMON_CLASSES_ABSTRACT})
  SET(VTK_CLASS_ABSTRACT_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_PVSERVERCOMMON_CLASSES_WRAP_EXCLUDE})
  SET(VTK_CLASS_WRAP_EXCLUDE_${class} 1)
ENDFOREACH(class)

==> paraview-3.10.1_1.tbz: lib/paraview-3.10/vtkPVServerCommonKit.cmake <==
# Directory containing class headers.
SET(VTK_PVSERVERCOMMON_HEADER_DIR "${VTK_INSTALL_PREFIX}/include/paraview-3.10")

# Classes in vtkPVServerCommon.
SET(VTK_PVSERVERCOMMON_CLASSES
  "vtkCacheSizeKeeper"
  "vtkCellIntegrator"
  "vtkClientConnection"
  "vtkConnectionIterator"
  "vtkFileSequenceParser"
  "vtkMPISelfConnection"
  "vtkMultiProcessControllerHelper"
  "vtkPriorityHelper"
  "vtkProcessModuleConnection"
  "vtkProcessModuleConnectionManager"
  "vtkProcessModule"
  "vtkProcessModuleAutoMPI"
  "vtkProcessModuleGUIHelper"
  "vtkPVAlgorithmPortsInformation"
  "vtkPVArrayInformation"
  "vtkPVCacheSizeInformation"
  "vtkPVClassNameInformation"
  "vtkPVClientServerIdCollectionInformation"
  "vtkPVCompositeDataInformation"
  "vtkPVCompositeDataInformationIterator"
  "vtkPVDataInformation"
  "vtkPVDataSetAttributesInformation"
  "vtkPVDataSizeInformation"
  "vtkPVDisplayInformation"
  "vtkPVEnvironmentInformation"
  "vtkPVEnvironmentInformationHelper"
  "vtkPVFileInformation"
  "vtkPVFileInformationHelper"
  "vtkPVGenericAttributeInformation"
  "vtkPVInformation"
  "vtkPVOpenGLExtensionsInformation"
  "vtkPVOptions"
  "vtkPVOptionsXMLParser"
  "vtkPVPlugin"
  "vtkPVPluginInformation"
  "vtkPVPluginLoader"
  "vtkPVProgressHandler"
  "vtkPVPythonModule"
  "vtkPVPythonPluginInterface"
  "vtkPVSelectionInformation"
  "vtkPVServerInformation"
  "vtkPVServerManagerPluginInterface"
  "vtkPVServerOptions"
  "vtkPVSILInformation"
  "vtkPVTemporalDataInformation"
  "vtkPVTestUtilities"
  "vtkPVTimerInformation"
  "vtkRemoteConnection"
  "vtkSelectionSerializer"
  "vtkSelfConnection"
  "vtkServerConnection"
  "vtkStringList"
  "vtkSynchronousMPISelfConnection"
  "vtkUndoElement"
  "vtkUndoSet"
  "vtkUndoStack"
  "vtkMPIMToNSocketConnection"
  "vtkMPIMToNSocketConnectionPortInformation"
  "vtkPVServerSocket"
  "vtkCommandOptions"
  "vtkCommandOptionsXMLParser"
  "vtkPVXMLParser"
  "vtkPVXMLElement")

# Abstract classes in vtkPVServerCommon.
SET(VTK_PVSERVERCOMMON_CLASSES_ABSTRACT
  "vtkCellIntegrator"
  "vtkProcessModuleConnection"
  "vtkProcessModuleGUIHelper"
  "vtkPVInformation"
  "vtkPVPlugin"
  "vtkPVPythonPluginInterface"
  "vtkPVServerManagerPluginInterface"
  "vtkRemoteConnection"
  "vtkUndoElement")

# Wrap-exclude classes in vtkPVServerCommon.
SET(VTK_PVSERVERCOMMON_CLASSES_WRAP_EXCLUDE
  "vtkConnectionIterator"
  "vtkProcessModuleAutoMPI"
  "vtkPVOptionsXMLParser"
  "vtkPVPlugin"
  "vtkPVPythonPluginInterface"
  "vtkPVServerManagerPluginInterface"
  "vtkPVServerOptions"
  "vtkPVTestUtilities"
  "vtkPVServerSocket"
  "vtkCommandOptionsXMLParser")

# Wrap-special classes in vtkPVServerCommon.
SET(VTK_PVSERVERCOMMON_CLASSES_WRAP_SPECIAL)

# Wrappable non-class headers for vtkPVServerCommon.
SET(VTK_PVSERVERCOMMON_WRAP_HEADERS)

# Set convenient variables to test each class.
FOREACH(class ${VTK_PVSERVERCOMMON_CLASSES})
  SET(VTK_CLASS_EXISTS_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_PVSERVERCOMMON_CLASSES_ABSTRACT})
  SET(VTK_CLASS_ABSTRACT_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_PVSERVERCOMMON_CLASSES_WRAP_EXCLUDE})
  SET(VTK_CLASS_WRAP_EXCLUDE_${class} 1)
ENDFOREACH(class)
FOREACH(class ${VTK_PVSERVERCOMMON_CLASSES_WRAP_SPECIAL})
  SET(VTK_CLASS_WRAP_SPECIAL_${class} 1)
ENDFOREACH(class)
